@@ -2,7 +2,7 @@ import importlib
 import json
 import os
 
-with importlib.resources.open_text("designer", "colors.json") as f:
+with open("../designer/data/" + "colors.json") as f:
     colors = json.load(f)
     f.close()
 
